@@ -13,17 +13,9 @@ try:
 except ImportError:
     from configparser import ConfigParser
 
-import six
-
 from .base import SquirroClient
 from .exceptions import NotFoundError
-from .util import deprecation
-
-try:
-    import ujson as json
-except ImportError:
-    import json
-
+from .util import _dumps, deprecation
 
 log = logging.getLogger(__name__)
 
@@ -38,14 +30,13 @@ try:
         except DependencyNotFound:
             return SquirroClient
 
-
 except ImportError:
 
     def get_client_cls():
         return SquirroClient
 
 
-class ItemUploader(object):
+class ItemUploader:
     """Item uploader class. Defaults are loaded from the ``.squirrorc`` file in
     the current user's home directory.
 
@@ -303,7 +294,7 @@ class ItemUploader(object):
                 if workflow["project_default"]:
                     return workflow
 
-        raise NotFoundError('Workflow "%s" with id "%s" was not found!' % (name, uuid))
+        raise NotFoundError(f'Workflow "{name}" with id "{uuid}" was not found!')
 
     def _load_config(self, kwargs):
         """Loads the configuration from file and merges it with the passed-in
@@ -325,8 +316,8 @@ class ItemUploader(object):
             config.update(dict(parser.items(config_section)))
 
         # update with kwargs actually passed in
-        config.update(dict([(k, v) for k, v in kwargs.items() if v is not None]))
-        config = dict([(k, v) for k, v in config.items() if k in self.CONFIG_KEYS])
+        config.update({k: v for k, v in kwargs.items() if v is not None})
+        config = {k: v for k, v in config.items() if k in self.CONFIG_KEYS}
 
         # transform integer arguments
         for key in self.INT_OPTIONS:
@@ -409,9 +400,7 @@ class ItemUploader(object):
                     break
 
             if getattr(self, "project_id", None) is None:
-                raise NotFoundError(
-                    "No project with title {0!r} found".format(project_title)
-                )
+                raise NotFoundError(f"No project with title {project_title!r} found")
 
     def _lookup_source(self, source_id=None, source_name=None):
         """Looks up a source with `source_id` called `source_name`."""
@@ -529,20 +518,19 @@ class ItemUploader(object):
         self._validate_upload_parameters(priority, pipeline_workflow_id)
         if not self.config.get("provider_api_url"):
             cluster = self.config["cluster"]
-            url = "{0}/api/provider/v1/{1}/projects/{2}/sources/{3}/push_items".format(
+            url = "{}/api/provider/v1/{}/projects/{}/sources/{}/push_items".format(
                 cluster, self.client.tenant, self.project_id, self.source_id
             )
         else:
             endpoint = self.config["provider_api_url"]
-            url = "{0}/v1/{1}/projects/{2}/sources/{3}/push_items".format(
+            url = "{}/v1/{}/projects/{}/sources/{}/push_items".format(
                 endpoint, self.client.tenant, self.project_id, self.source_id
             )
-        headers = {"Content-Type": "application/json"}
         params = {"priority": priority}
         if pipeline_workflow_id is not None:
             params.update({"pipeline_workflow_id": pipeline_workflow_id})
 
-        self._upload(items, url, params, headers, num_retries, delay, backoff)
+        self._upload(items, url, params, num_retries, delay, backoff)
 
     def upload_rows(
         self,
@@ -575,15 +563,14 @@ class ItemUploader(object):
         self._validate_upload_parameters(priority, pipeline_workflow_id)
         if not self.config.get("provider_api_url"):
             cluster = self.config["cluster"]
-            url = "{0}/api/provider/v1/{1}/projects/{2}/sources/{3}/push_rows".format(
+            url = "{}/api/provider/v1/{}/projects/{}/sources/{}/push_rows".format(
                 cluster, self.client.tenant, self.project_id, self.source_id
             )
         else:
             endpoint = self.config["provider_api_url"]
-            url = "{0}/v1/{1}/projects/{2}/sources/{3}/push_rows".format(
+            url = "{}/v1/{}/projects/{}/sources/{}/push_rows".format(
                 endpoint, self.client.tenant, self.project_id, self.source_id
             )
-        headers = {"Content-Type": "application/json"}
         params = {"priority": priority}
         if pipeline_workflow_id is not None:
             params.update({"pipeline_workflow_id": pipeline_workflow_id})
@@ -602,7 +589,7 @@ class ItemUploader(object):
             base64_encoded_columns = ",".join(col for col in base64_encoded_columns)
             params.update({"base64_encoded_columns": base64_encoded_columns})
 
-        self._upload(rows, url, params, headers, num_retries, delay, backoff)
+        self._upload(rows, url, params, num_retries, delay, backoff)
 
     def _validate_upload_parameters(self, priority, pipeline_workflow_id):
         """Validations for parameters to the `upload` function."""
@@ -625,7 +612,7 @@ class ItemUploader(object):
         batch_size = self.config["batch_size"]
 
         if batch_size == -1:
-            items_bytes_size = sys.getsizeof(json.dumps(items))
+            items_bytes_size = sys.getsizeof(_dumps(items))
             if items_bytes_size < MAX_BYTE_SIZE:
                 batch_size = len(items)
             else:
@@ -647,7 +634,7 @@ class ItemUploader(object):
 
         keywords = item["keywords"]
         for key, value in keywords.items():
-            if isinstance(value, (Number, six.string_types)):
+            if isinstance(value, (Number, str)):
                 keywords[key] = [value]
             elif isinstance(value, list):
                 keywords[key] = value
@@ -655,11 +642,11 @@ class ItemUploader(object):
                 keywords[key] = list(value)
             else:
                 raise TypeError(
-                    "Cannot validate the keyword {0}. Type {1} "
+                    "Cannot validate the keyword {}. Type {} "
                     "is not supported".format(key, type(value))
                 )
 
-    def _upload(self, items, url, params, headers, num_retries, delay, backoff):
+    def _upload(self, items, url, params, num_retries, delay, backoff):
         if not items:
             log.info("Asked to upload empty item list. Skipping.")
             return
@@ -670,12 +657,16 @@ class ItemUploader(object):
             mdelay = delay
             for item in items[idx : idx + batch_size]:
                 self._fixup_keywords(item)
-            data = json.dumps(items[idx : idx + batch_size])
+            data = _dumps(items[idx : idx + batch_size])
             for i in range(num_retries + 1):
                 if i != 0:
                     log.warning(f"Retrying {i} of {num_retries}")
                 res = self.client._perform_request(
-                    "post", url, params=params, data=data, headers=headers
+                    "post",
+                    url,
+                    params=params,
+                    data=data,
+                    headers={"Content-Type": "application/json"},
                 )
                 if res.status_code in self.non_retry_list:
                     self.client._process_response(res, [202])
