@@ -321,12 +321,13 @@ class TopicApiBaseMixin:
 
         :param project_id: Project identifier.
         :param query: Optional query to run.
-        :param query_context: Dictionary containing context of the query:
+        :param query_context: Dictionary with more context of the user's input / intent:
 
                 - `searchbar_query` : Terms that user typed in a searchbar.
                 - `dashboard_filters` : Additional filter-queries provided via dashboard or widget configuration.
                 - `like` : Additional input to perform approximate search on.
                          For now `like` is considered to be a long string (e.g. paragraphs)
+                - `parsed` : The parsed, analysed and enriched representation of the `searchbar_query` (response of the configured `query-processing workflow <https://go.squirro.com/libnlp-query-processing>`_)
 
         :param start: Zero based starting point.
         :param count: Maximum number of items to return.
@@ -336,8 +337,7 @@ class TopicApiBaseMixin:
             are: `query` (boolean) if True the response will contain highlight
             information. `smartfilters` (list): List of Smart Filter names to
             be highlighted.
-        :param spellcheck: (Dictionary) Apply spellchecking on the given query terms.
-            Spellchecking is performed against the provided field (full elastic field name).
+        :param spellcheck: If `True` check the spelling of the provided query.
         :param options: Dictionary of options that influence the
             result-set. Valid options are:
 
@@ -397,7 +397,7 @@ class TopicApiBaseMixin:
                         project_id="DSuNrcnlSc6x5SJZh02IyQ",
                         query="vimus",
                         count=2,
-                        spellcheck={"text":query,"field":"body.en.unstemmed"})
+                        spellcheck=True)
             {'count': 0,
              'items': [],
              'now': '2022-03-21T16:55:38',
@@ -445,6 +445,13 @@ class TopicApiBaseMixin:
                 "Use `scan` method to perform scrolling."
             )
             kwargs.pop("scroll")
+        if args.get("spellcheck") and isinstance(args["spellcheck"], dict):
+            logging.warning(
+                "Using dictionary in the `spellcheck` parameter is deprecated. "
+                "Use the `bool` value instead that specifies whether to check the "
+                "spelling of the provided query."
+            )
+            args["spellcheck"] = True
         args.update(kwargs)
         data = {k: v for k, v in list(args.items()) if v is not None}
 
@@ -1206,6 +1213,7 @@ class TopicApiBaseMixin:
         query=None,
         scroll="5m",
         preserve_order=False,
+        preserve_scroll_order=False,
         count=1000,
         fields=None,
         highlight=None,
@@ -1230,7 +1238,14 @@ class TopicApiBaseMixin:
             /reference/current/search-request-scroll.html
             for more details.
         :param preserve_order: This will cause the scroll to paginate with preserving the order.
-            Note that this can be an extremely expensive operation and can easily lead to unpredictable results, use with caution
+            Note that this can be an extremely expensive operation and can easily lead to unpredictable results, use with caution.
+
+            .. deprecated:: 3.6.4
+
+                Use the `preserve_scroll_order` parameter.
+
+        :param preserve_scroll_order: This will cause the scroll to paginate with preserving the order.
+            Note that this can be an extremely expensive operation and can easily lead to unpredictable results, use with caution.
         :param count: The number of results fetched per batch. You only need
             to adjust this if you e.g. have very big documents. The maximum
             value that can be set is 10'000.
@@ -1260,7 +1275,7 @@ class TopicApiBaseMixin:
         Example::
 
             >>> for item in client.scan(project_id='Sz7LLLbyTzy_SddblwIxaA', query='country:CH AND plants',
-            ...                         count=500, scroll='1m', preserve_order=True):
+            ...                         count=500, scroll='1m', preserve_scroll_order=True):
                     # process matched item
         """
         assert scroll, "`scroll` cannot be empty for scan."
@@ -1275,12 +1290,19 @@ class TopicApiBaseMixin:
             "project_id": project_id,
         }
 
+        if preserve_order:
+            logging.warning(
+                "The `preserve_order` parameter is deprecated. "
+                "Use the `preserve_scroll_order` instead."
+            )
+            preserve_scroll_order = preserve_order
+
         headers = {"Content-Type": "application/json"}
 
         args = {
             "query": query,
             "scroll": scroll,
-            "preserve_order": preserve_order,
+            "preserve_scroll_order": preserve_scroll_order,
             "count": min(count, 10000),
             "child_count": min(child_count, 100),
             "fields": fields,
