@@ -4,7 +4,7 @@ import logging
 log = logging.getLogger(__name__)
 
 
-class CommunitySubscriptionsMixin(object):
+class CommunitySubscriptionsMixin:
     def get_community_subscriptions(self, project_id, include_count_of_items=False):
         """Returns all community subscriptions for a project and a user.
 
@@ -34,11 +34,11 @@ class CommunitySubscriptionsMixin(object):
 
         TODO: allow for specifying user id
         """
-        url = "%(ep)s/v0/%(tenant)s/projects/%(project_id)s/community_subscriptions" % {
-            "ep": self.topic_api_url,
-            "tenant": self.tenant,
-            "project_id": project_id,
-        }
+        url = "{ep}/v0/{tenant}/projects/{project_id}/community_subscriptions".format(
+            ep=self.topic_api_url,
+            tenant=self.tenant,
+            project_id=project_id,
+        )
         params = {
             "include_count_of_items": include_count_of_items,
         }
@@ -46,13 +46,19 @@ class CommunitySubscriptionsMixin(object):
         return self._process_response(res)
 
     def new_community_subscriptions(
-        self, project_id, community_ids, remove_existing_subscriptions=False
+        self,
+        project_id,
+        community_ids,
+        remove_existing_subscriptions=False,
+        user_id=None,
     ):
         """Creates a new community subscription for a project
         given the community_id
 
         :param project_id: Project Identifier
-        :param name: community type name
+        :param community_ids: Ids of the communities to subscribe to
+        :param remove_existing_subscriptions: Boolean flag to remove existing subscriptions
+        :param user_id: Id of the user subscribing to the community ids
 
         Example::
 
@@ -75,6 +81,7 @@ class CommunitySubscriptionsMixin(object):
         data = {
             "community_ids": community_ids,
             "remove_existing_subscriptions": remove_existing_subscriptions,
+            "user_id": user_id,
         }
 
         headers = {"Content-Type": "application/json"}
